@@ -31,7 +31,7 @@ pub const TYPE_IS_ATTR: &str = "TYPE";
 pub const TYPE_REQUIRES_ATTR: &str = "TYPE_REQUIRES";
 pub const TYPE_HAS_ATTR: &str = "TYPE_HAS";
 pub const TYPE_ID_ATTR: &str = "TYPE_ID";
-pub const TYPE_INSTANCED_ATTR: &str = "TYPE_INSTANCED";
+pub const TYPE_INSTANCES_ATTR: &str = "TYPE_INSTANCES";
 pub const IS_OF_TYPE_ATTR: &str = "IS";
 
 lazy_static! {
