@@ -3,7 +3,7 @@ use crate::database::{
     bulk_retrieve_objects, file_set_valid, insert_entry, insert_file, query, retrieve_all_files,
     DbPool, Entry, EntryQuery, EntryValue, InvariantEntry, Query, QueryComponent, QueryPart,
     DATABASE_FILENAME, IS_OF_TYPE_ATTR, TYPE_ADDR, TYPE_HAS_ATTR, TYPE_ID_ATTR,
-    TYPE_INSTANCED_ATTR, TYPE_IS_ATTR, TYPE_REQUIRES_ATTR,
+    TYPE_INSTANCES_ATTR, TYPE_IS_ATTR, TYPE_REQUIRES_ATTR,
 };
 use crate::hash::Hashable;
 use crate::jobs::{Job, JobContainer, JobId, State};
@@ -60,7 +60,6 @@ fn initialize_types(pool: &DbPool) -> Result<()> {
     // BLOB_TYPE
     insert_entry(&pool.get()?, Entry::try_from(&*BLOB_TYPE_INVARIANT)?)?;
     upend_insert_addr!(&pool.get()?, BLOB_TYPE_ADDR, IS_OF_TYPE_ATTR, TYPE_ADDR);
-    upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_INSTANCED_ATTR, FILE_TYPE);
     upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_MTIME_KEY);
     upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_SIZE_KEY);
     upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_MIME_KEY);
@@ -68,6 +67,12 @@ fn initialize_types(pool: &DbPool) -> Result<()> {
     // FILE_TYPE
     insert_entry(&pool.get()?, Entry::try_from(&*FILE_TYPE_INVARIANT)?)?;
     upend_insert_addr!(&pool.get()?, FILE_TYPE_ADDR, IS_OF_TYPE_ATTR, TYPE_ADDR);
+    upend_insert_val!(
+        &pool.get()?,
+        FILE_TYPE_ADDR,
+        TYPE_INSTANCES_ATTR,
+        FILE_IDENTITY_KEY
+    );
     upend_insert_val!(&pool.get()?, FILE_TYPE_ADDR, TYPE_ID_ATTR, FILENAME_KEY);
     upend_insert_val!(
         &pool.get()?,
